aboutsummaryrefslogtreecommitdiffstats
path: root/bitbake-dev/lib/bb/command.py
diff options
context:
space:
mode:
Diffstat (limited to 'bitbake-dev/lib/bb/command.py')
-rw-r--r--bitbake-dev/lib/bb/command.py16
1 files changed, 9 insertions, 7 deletions
diff --git a/bitbake-dev/lib/bb/command.py b/bitbake-dev/lib/bb/command.py
index 4cab78e43b..9226a2772f 100644
--- a/bitbake-dev/lib/bb/command.py
+++ b/bitbake-dev/lib/bb/command.py
@@ -203,23 +203,25 @@ class CommandsAsync:
command.finishAsyncCommand()
showVersions.needcache = True
- def showEnvironmentPackage(self, command, params):
+ def showEnvironmentTarget(self, command, params):
"""
- Print the environment of a recipe
+ Print the environment of a target recipe
+ (needs the cache to work out which recipe to use)
"""
- bfile = params[0]
- pkg = params[1]
+ pkg = params[0]
- command.cooker.showEnvironment(bfile, pkg)
+ command.cooker.showEnvironment(None, pkg)
command.finishAsyncCommand()
- showEnvironmentPackage.needcache = True
+ showEnvironmentTarget.needcache = True
def showEnvironment(self, command, params):
"""
Print the standard environment
+ or if specified the environment for a specified recipe
"""
+ bfile = params[0]
- command.cooker.showEnvironment()
+ command.cooker.showEnvironment(bfile)
command.finishAsyncCommand()
showEnvironment.needcache = False